===============
 INSPIRE-Utils
===============

.. image:: https://travis-ci.org/inspirehep/inspire-utils.svg?branch=master
    :target: https://travis-ci.org/inspirehep/inspire-utils

.. image:: https://coveralls.io/repos/github/inspirehep/inspire-utils/badge.svg?branch=master
    :target: https://coveralls.io/github/inspirehep/inspire-utils?branch=master

About
=====

INSPIRE-specific utils.
